@@ -2,6 +2,7 @@
     use strict;
     use warnings;
     use Math::GMPz::Random;
+    use Math::GMPz::V;
     require Exporter;
     *import = \&Exporter::import;
     require DynaLoader;
@@ -17,6 +18,7 @@
     use constant _MATH_GMP_T    => 9;
     use constant _MATH_MPC_T    => 10;
     use constant GMPZ_PV_NV_BUG => Math::GMPz::Random::_has_pv_nv_bug();
+    use constant GMPZ_WIN32_FMT_BUG => Math::GMPz::V::_buggy();
 
 use subs qw( __GNU_MP_VERSION __GNU_MP_VERSION_MINOR __GNU_MP_VERSION_PATCHLEVEL
              __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS GMP_LIMB_BITS GMP_NAIL_BITS
@@ -67,7 +69,7 @@ __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS IOK_flag NOK_flag POK_flag
     );
 
     my @tagged = qw(
-GMPZ_PV_NV_BUG MATH_GMPz_IV_MAX MATH_GMPz_IV_MIN MATH_GMPz_UV_MAX
+GMPZ_PV_NV_BUG GMPZ_WIN32_FMT_BUG MATH_GMPz_IV_MAX MATH_GMPz_IV_MIN MATH_GMPz_UV_MAX
 Rmpz_abs Rmpz_add Rmpz_add_ui Rmpz_addmul Rmpz_addmul_ui Rmpz_and Rmpz_bin_ui
 Rmpz_bin_uiui Rmpz_bin_si Rmpz_cdiv_q Rmpz_cdiv_q_2exp Rmpz_cdiv_q_ui Rmpz_cdiv_qr
 Rmpz_cdiv_qr_ui Rmpz_cdiv_r Rmpz_cdiv_r_2exp Rmpz_cdiv_r_ui Rmpz_cdiv_ui
@@ -122,7 +124,7 @@ zgmp_urandomb_ui zgmp_urandomm_ui
     );
 
     @Math::GMPz::EXPORT_OK = (@untagged, @tagged);
-    our $VERSION = '0.59';
+    our $VERSION = '0.62';
     #$VERSION = eval $VERSION;
 
     Math::GMPz->DynaLoader::bootstrap($VERSION);
@@ -135,12 +137,14 @@ zgmp_urandomb_ui zgmp_urandomm_ui
     $Math::GMPz::utf8_no_fail      = 0; # warn  if $Math::GMPz::utf8_no_croak is true &&
                                         #          utf8::downgrade fails in Rmpz_import.
 
-    $Math::GMPz::RETYPE = 0; # set to 1 to enable a Math::GMPz object to be coerced to
+    $Math::GMPz::RETYPE = 1; # This variable used to be initially set to 0, but
+                             # this has changed, beginning with Math::GMPz-0.62.
+                             # This enables a Math::GMPz object to be coerced to
                              # a Math::GMPq or Math::MPFR object in certain overloaded
                              # operations. (See the 'OPERATOR OVERLOADING' section of
                              # the POD documentation for details.)
-                             # With this variable set to 0, these "certain overloaded
-                             # operations" alluded to will throw a fatal error.
+                             # Setting this variable to 0 will cause these "certain
+                             # overloaded operations" to throw a fatal error.
 
     %Math::GMPz::EXPORT_TAGS =(mpz => \@tagged);
 
